summaryrefslogtreecommitdiffhomepage
path: root/cheatsheet/raylib_core.c
diff options
context:
space:
mode:
authorraysan5 <[email protected]>2020-03-24 16:15:57 +0100
committerraysan5 <[email protected]>2020-03-24 16:15:57 +0100
commit1c448b37b3c387814f2b122efc08a951958ad88a (patch)
treec9d609508e467fa6239ee4a1f67859443342402a /cheatsheet/raylib_core.c
parente5ae10033f1138a54b21c9167a84286335132a4c (diff)
downloadraylib.com-1c448b37b3c387814f2b122efc08a951958ad88a.tar.gz
raylib.com-1c448b37b3c387814f2b122efc08a951958ad88a.zip
Update cheatsheet with last minute functions
Diffstat (limited to 'cheatsheet/raylib_core.c')
-rw-r--r--cheatsheet/raylib_core.c4
1 files changed, 3 insertions, 1 deletions
diff --git a/cheatsheet/raylib_core.c b/cheatsheet/raylib_core.c
index 377c4ec..904b542 100644
--- a/cheatsheet/raylib_core.c
+++ b/cheatsheet/raylib_core.c
@@ -84,7 +84,9 @@
// Files management functions
unsigned char *LoadFileData(const char *fileName, int *bytesRead); // Load file data as byte array (read)
- void SaveFileData(const char *fileName, void *data, int bytesToWrite); // Save data to file from byte array (write)
+ void SaveFileData(const char *fileName, void *data, int bytesToWrite); // Save data to file from byte array (write)
+ char *LoadFileText(const char *fileName); // Load text data from file (read), returns a '\0' terminated string
+ void SaveFileText(const char *fileName, char *text); // Save text data to file (write), string must be '\0' terminated
bool FileExists(const char *fileName); // Check if file exists
bool IsFileExtension(const char *fileName, const char *ext); // Check file extension
bool DirectoryExists(const char *dirPath); // Check if a directory path exists